@@ -10,8 +10,10 @@ def join_url(url, *paths):
     """
     Joins individual URL strings together, and returns a single string.
 
-    >>> util.join_url("example.com", "index.html")
-    'example.com/index.html'
+    Usage::
+
+        >>> util.join_url("example.com", "index.html")
+        'example.com/index.html'
     """
     for path in paths:
         url = re.sub(r'/?$', re.sub(r'^/?', '/', path), url)
@@ -19,6 +21,14 @@ def join_url(url, *paths):
 
 
 def join_url_params(url, params):
+    """Constructs percent-encoded query string from given parms dictionary
+     and appends to given url
+
+    Usage::
+
+        >>> util.join_url_params("example.com/index.html", {"page-id": 2, "Company": "Pay Pal"})
+        example.com/index.html?page-id=2&Company=Pay+Pal
+    """
     return url + "?" + urlencode(params)
 
 
@@ -26,9 +36,10 @@ def merge_dict(data, *override):
     """
     Merges any number of dictionaries together, and returns a single dictionary
 
-    >>> util.merge_dict ({"foo": "bar"}, {1: 2}, {"Pay": "Pal"})
-    {1: 2, 'foo': 'bar', 'Pay': 'Pal'}
-    >>>
+    Usage::
+
+        >>> util.merge_dict ({"foo": "bar"}, {1: 2}, {"Pay": "Pal"})
+        {1: 2, 'foo': 'bar', 'Pay': 'Pal'}
     """
     result = {}
     for current_dict in (data,) + override:
